# kuzu-wasm/sync
Welcome to the documentation of `kuzu-wasm`, the WebAssembly build of Kuzu in-process property graph database management system. 
You are currently viewing the *synchronous* JavaScript API documentation. 
This version of the module is synchronous and does not require any callbacks (other than the module initialization).
This version is good for scripting / CLI / prototyping purposes,
but is not recommended to be used in GUI applications or web servers because it may block the main thread and cause unexpected freezes. 

The documentation of each class can be found by clicking on the links in the sidebar.

For package-level functions, please refer to the documentation of the module `kuzu-wasm` from the sidebar.

A summary of the files in this module is listed below: